# ColumnarFrame

カラムベースでデータを扱うためのライブラリです。
ある程度Pandasのように操作できるような形を目指しています。

This is a library for handling column-based data.
It is intended to be operated like Pandas to some extent.

## Memo

* unittest

```
poetry run python -m unittest discover
```

* build

```
poetry build
```

* publish(Test)

```
poetry publish -r testpypi
```

* public(real)

```
poetry publish
```

* lib install

```
poetry add xxxx
```

